@@ -1,7 +1,8 @@
 from sqlalchemy.ext.declarative import declared_attr
+from sqlalchemy import Table, Column, Integer, String, MetaData, ForeignKey, DateTime
 import sqlalchemy.types as types
 from sqlalchemy.types import String
-from app import db
+# from app import db
 from flask import g
 import uuid
 import datetime
@@ -30,27 +31,27 @@ class AuditMixin(BaseMixin):
     Mixin for models, add 4 cols to stamp, time and user on
     creation and modification
     """
-    created_on = db.Column(db.DateTime, default=datetime.datetime.now,nullable=False)
-    changed_on = db.Column(db.DateTime, default=datetime.datetime.now,
+    created_on = Column(DateTime, default=datetime.datetime.now,nullable=False)
+    changed_on = Column(DateTime, default=datetime.datetime.now,
                             onupdate=datetime.datetime.now,nullable=False)
 
     @declared_attr
     def created_by_fk(cls):
-        return db.Column(db.Integer, db.ForeignKey('user.id'),
+        return Column(Integer, ForeignKey('user.id'),
                 default=cls.get_user_id,nullable=False)
 
     @declared_attr
     def created_by(cls):
-        return db.relationship("User", primaryjoin='%s.created_by_fk == User.id'%cls.__name__)
+        return relationship("User", primaryjoin='%s.created_by_fk == User.id'%cls.__name__)
 
     @declared_attr
     def changed_by_fk(cls):
-        return db.Column(db.Integer, db.ForeignKey('user.id'),
+        return Column(Integer, ForeignKey('user.id'),
                 default=cls.get_user_id,onupdate=cls.get_user_id,nullable=False)
 
     @declared_attr
     def changed_by(cls):
-        return db.relationship("User", primaryjoin='%s.changed_by_fk == User.id'%cls.__name__)
+        return relationship("User", primaryjoin='%s.changed_by_fk == User.id'%cls.__name__)
 
 
     @classmethod
